[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - pype32.excep.PyPe32Exception: Base exception class.
        - pype32.excep.ArrayTypeException: Raised when creating an unsupported type of array.
        - pype32.excep.DataLengthException: Raised when data lengths does not match.
        - pype32.excep.DataMismatchException: Raised when two different types of data does not match.
        - pype32.excep.DirectoryEntriesLengthException: Raised when the the number of entries in a DataDirectory object is different from consts.IMAGE_NUMBEROF_DIRECTORY_ENTRIES.
        - pype32.excep.DirectoryEntryException: This exception must be raised when an error with the Directory is found.
        - pype32.excep.InstanceErrorException: This exception is raised when an instance parameter was not specified.
        - pype32.excep.InvalidParameterException: Raised when an invalid parameter is received.
        - pype32.excep.NotValidPathException: Raised when a path wasn't found or it is an invalid path.
        - pype32.excep.PEException: Raised when an invalid field on the PE instance was found.
        - pype32.excep.ReadDataOffsetException: This exception must be raised when reading from an invalid offset.
        - pype32.excep.SectionHeadersException: Raised when an error related to a pype32.SectionHeader or pype32.SectionHeaders is found.
        - pype32.excep.TypeNotSupportedException: This exception must be used when an invalid data type is used within the library.
        - pype32.excep.WriteDataOffsetException: This exception must be raised when writing to an invalid offset.
        - pype32.excep.WrongOffsetValueException: Used primary by the ReadData and WriteData object in read/write operations when an invalid offset value was used.
      - pype32.excep.PyPe32Warning: Base warning class.
        - pype32.excep.PEWarning: Raised when a suspicious value is found into the PE instance.
  - pype32.baseclasses.BaseStructClass: Base class containing methods used by many others classes in the library.
    - pype32.pype32.DosHeader: DosHeader object.
    - pype32.directories.ExportTableEntry: ExportTableEntry object.
    - pype32.pype32.FileHeader: FileHeader object.
    - pype32.directories.ImageBaseRelocationEntry: ImageBaseRelocationEntry object.
    - pype32.directories.ImageBoundForwarderRefEntry: ImageBoundForwarderRefEntry object.
    - pype32.directories.ImageBoundImportDescriptorEntry: ImageBoundImportDescriptorEntry object.
    - pype32.directories.ImageDebugDirectory: ImageDebugDirectory object.
    - pype32.directories.ImageExportTable: ImageExportTable object.
    - pype32.directories.ImageImportDescriptorEntry: ImageImportDescriptorEntry object.
    - pype32.directories.ImageImportDescriptorMetaData: ImageImportDescriptorMetaData object.
    - pype32.directories.ImportAddressTableEntry: ImportAddressTableEntry object.
    - pype32.directories.ImportAddressTableEntry64: ImportAddressTableEntry64 object.
    - pype32.directories.NETDirectory: NETDirectory object.
    - pype32.directories.NetDirectory: NetDirectory object.
    - pype32.directories.NetMetaDataHeader: NetMetaDataHeader object.
    - pype32.directories.NetMetaDataStreamEntry: NetMetaDataStreamEntry object.
    - pype32.directories.NetMetaDataTableHeader: NetMetaDataTableHeader object.
    - pype32.directories.NetMetaDataTables: NetMetaDataTables object.
    - pype32.pype32.NtHeaders: NtHeaders object.
    - pype32.pype32.OptionalHeader: OptionalHeader object.
    - pype32.pype32.OptionalHeader64: OptionalHeader64 object.
    - pype32.pype32.SectionHeader: SectionHeader object.
    - pype32.directories.TLSDirectory: TLS directory object.
    - pype32.directories.TLSDirectory64: TLSDirectory64 object.
  - pype32.baseclasses.DataTypeBaseClass
    - pype32.datatypes.BYTE: Byte object.
    - pype32.datatypes.DWORD: Dword object.
    - pype32.datatypes.QWORD: Qword object.
    - pype32.datatypes.WORD: Word object.
  - pype32.datadirs.Directory: Directory object.
  - pype32.pype32.PE: PE object.
  - pype32.utils.ReadData: Returns a ReadData-like stream object.
  - pype32.datatypes.String: String object.
    - pype32.datatypes.AlignedString: Aligned string object.
  - pype32.utils.WriteData: Return a WriteData-like stream object for writing.
  - list: list() -> new empty list list(iterable) -> new list initialized from iterable's items
    - pype32.datatypes.Array: Array object.
    - pype32.datadirs.DataDirectory: DataDirectory object.
    - pype32.directories.ExportTable: Array of ExportTableEntry objects.
    - pype32.directories.ImageBaseRelocation: ImageBaseRelocation array.
    - pype32.directories.ImageBoundForwarderRef: ImageBoundForwarderRef array object.
    - pype32.directories.ImageBoundImportDescriptor: ImageBoundImportDescriptor object.
    - pype32.directories.ImageDebugDirectories: ImageDebugDirectories object.
    - pype32.directories.ImageImportDescriptor: ImageImportDescriptor object.
    - pype32.directories.ImportAddressTable: Array of ImportAddressTableEntry objects.
    - pype32.directories.NetMetaDataStreams: NetMetaDataStreams object.
    - pype32.pype32.SectionHeaders: SectionHeaders object.
    - pype32.pype32.Sections: Sections object.